@@ -82,7 +82,7 @@ class Exceptions:
 
 class ComputeOptimizerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html)
     """
 
@@ -98,22 +98,22 @@ class ComputeOptimizerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#can_paginate)
         """
 
     def describe_recommendation_export_jobs(
         self,
         *,
-        jobIds: Sequence[str] = None,
-        filters: Sequence["JobFilterTypeDef"] = None,
-        nextToken: str = None,
-        maxResults: int = None
+        jobIds: Sequence[str] = ...,
+        filters: Sequence["JobFilterTypeDef"] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> DescribeRecommendationExportJobsResponseTypeDef:
         """
         Describes recommendation export jobs created in the last seven days.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#describe_recommendation_export_jobs)
         """
 
@@ -121,17 +121,17 @@ class ComputeOptimizerClient(BaseClient):
         self,
         *,
         s3DestinationConfig: "S3DestinationConfigTypeDef",
-        accountIds: Sequence[str] = None,
-        filters: Sequence["FilterTypeDef"] = None,
-        fieldsToExport: Sequence[ExportableAutoScalingGroupFieldType] = None,
-        fileFormat: Literal["Csv"] = None,
-        includeMemberAccounts: bool = None,
-        recommendationPreferences: "RecommendationPreferencesTypeDef" = None
+        accountIds: Sequence[str] = ...,
+        filters: Sequence["FilterTypeDef"] = ...,
+        fieldsToExport: Sequence[ExportableAutoScalingGroupFieldType] = ...,
+        fileFormat: Literal["Csv"] = ...,
+        includeMemberAccounts: bool = ...,
+        recommendationPreferences: "RecommendationPreferencesTypeDef" = ...
     ) -> ExportAutoScalingGroupRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for Auto Scaling groups.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_auto_scaling_group_recommendations)
         """
 
@@ -139,16 +139,16 @@ class ComputeOptimizerClient(BaseClient):
         self,
         *,
         s3DestinationConfig: "S3DestinationConfigTypeDef",
-        accountIds: Sequence[str] = None,
-        filters: Sequence["EBSFilterTypeDef"] = None,
-        fieldsToExport: Sequence[ExportableVolumeFieldType] = None,
-        fileFormat: Literal["Csv"] = None,
-        includeMemberAccounts: bool = None
+        accountIds: Sequence[str] = ...,
+        filters: Sequence["EBSFilterTypeDef"] = ...,
+        fieldsToExport: Sequence[ExportableVolumeFieldType] = ...,
+        fileFormat: Literal["Csv"] = ...,
+        includeMemberAccounts: bool = ...
     ) -> ExportEBSVolumeRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for Amazon EBS volumes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ebs_volume_recommendations)
         """
 
@@ -156,17 +156,17 @@ class ComputeOptimizerClient(BaseClient):
         self,
         *,
         s3DestinationConfig: "S3DestinationConfigTypeDef",
-        accountIds: Sequence[str] = None,
-        filters: Sequence["FilterTypeDef"] = None,
-        fieldsToExport: Sequence[ExportableInstanceFieldType] = None,
-        fileFormat: Literal["Csv"] = None,
-        includeMemberAccounts: bool = None,
-        recommendationPreferences: "RecommendationPreferencesTypeDef" = None
+        accountIds: Sequence[str] = ...,
+        filters: Sequence["FilterTypeDef"] = ...,
+        fieldsToExport: Sequence[ExportableInstanceFieldType] = ...,
+        fileFormat: Literal["Csv"] = ...,
+        includeMemberAccounts: bool = ...,
+        recommendationPreferences: "RecommendationPreferencesTypeDef" = ...
     ) -> ExportEC2InstanceRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for Amazon EC2 instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ec2_instance_recommendations)
         """
 
@@ -174,80 +174,80 @@ class ComputeOptimizerClient(BaseClient):
         self,
         *,
         s3DestinationConfig: "S3DestinationConfigTypeDef",
-        accountIds: Sequence[str] = None,
-        filters: Sequence["LambdaFunctionRecommendationFilterTypeDef"] = None,
-        fieldsToExport: Sequence[ExportableLambdaFunctionFieldType] = None,
-        fileFormat: Literal["Csv"] = None,
-        includeMemberAccounts: bool = None
+        accountIds: Sequence[str] = ...,
+        filters: Sequence["LambdaFunctionRecommendationFilterTypeDef"] = ...,
+        fieldsToExport: Sequence[ExportableLambdaFunctionFieldType] = ...,
+        fileFormat: Literal["Csv"] = ...,
+        includeMemberAccounts: bool = ...
     ) -> ExportLambdaFunctionRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for Lambda functions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_lambda_function_recommendations)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#generate_presigned_url)
         """
 
     def get_auto_scaling_group_recommendations(
         self,
         *,
-        accountIds: Sequence[str] = None,
-        autoScalingGroupArns: Sequence[str] = None,
-        nextToken: str = None,
-        maxResults: int = None,
-        filters: Sequence["FilterTypeDef"] = None,
-        recommendationPreferences: "RecommendationPreferencesTypeDef" = None
+        accountIds: Sequence[str] = ...,
+        autoScalingGroupArns: Sequence[str] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...,
+        filters: Sequence["FilterTypeDef"] = ...,
+        recommendationPreferences: "RecommendationPreferencesTypeDef" = ...
     ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
         """
         Returns Auto Scaling group recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_auto_scaling_group_recommendations)
         """
 
     def get_ebs_volume_recommendations(
         self,
         *,
-        volumeArns: Sequence[str] = None,
-        nextToken: str = None,
-        maxResults: int = None,
-        filters: Sequence["EBSFilterTypeDef"] = None,
-        accountIds: Sequence[str] = None
+        volumeArns: Sequence[str] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...,
+        filters: Sequence["EBSFilterTypeDef"] = ...,
+        accountIds: Sequence[str] = ...
     ) -> GetEBSVolumeRecommendationsResponseTypeDef:
         """
         Returns Amazon Elastic Block Store (Amazon EBS) volume recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ebs_volume_recommendations)
         """
 
     def get_ec2_instance_recommendations(
         self,
         *,
-        instanceArns: Sequence[str] = None,
-        nextToken: str = None,
-        maxResults: int = None,
-        filters: Sequence["FilterTypeDef"] = None,
-        accountIds: Sequence[str] = None,
-        recommendationPreferences: "RecommendationPreferencesTypeDef" = None
+        instanceArns: Sequence[str] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...,
+        filters: Sequence["FilterTypeDef"] = ...,
+        accountIds: Sequence[str] = ...,
+        recommendationPreferences: "RecommendationPreferencesTypeDef" = ...
     ) -> GetEC2InstanceRecommendationsResponseTypeDef:
         """
         Returns Amazon EC2 instance recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_instance_recommendations)
         """
 
@@ -259,13 +259,13 @@ class ComputeOptimizerClient(BaseClient):
         period: int,
         startTime: Union[datetime, str],
         endTime: Union[datetime, str],
-        recommendationPreferences: "RecommendationPreferencesTypeDef" = None
+        recommendationPreferences: "RecommendationPreferencesTypeDef" = ...
     ) -> GetEC2RecommendationProjectedMetricsResponseTypeDef:
         """
         Returns the projected utilization metrics of Amazon EC2 instance
         recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_recommendation_projected_metrics)
         """
 
@@ -274,58 +274,58 @@ class ComputeOptimizerClient(BaseClient):
         Returns the enrollment (opt in) status of an account to the Compute Optimizer
         service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_enrollment_status)
         """
 
     def get_enrollment_statuses_for_organization(
         self,
         *,
-        filters: Sequence["EnrollmentFilterTypeDef"] = None,
-        nextToken: str = None,
-        maxResults: int = None
+        filters: Sequence["EnrollmentFilterTypeDef"] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> GetEnrollmentStatusesForOrganizationResponseTypeDef:
         """
         Returns the Compute Optimizer enrollment (opt-in) status of organization member
         accounts, if your account is an organization management account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_statuses_for_organization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_statuses_for_organization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_enrollment_statuses_for_organization)
         """
 
     def get_lambda_function_recommendations(
         self,
         *,
-        functionArns: Sequence[str] = None,
-        accountIds: Sequence[str] = None,
-        filters: Sequence["LambdaFunctionRecommendationFilterTypeDef"] = None,
-        nextToken: str = None,
-        maxResults: int = None
+        functionArns: Sequence[str] = ...,
+        accountIds: Sequence[str] = ...,
+        filters: Sequence["LambdaFunctionRecommendationFilterTypeDef"] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> GetLambdaFunctionRecommendationsResponseTypeDef:
         """
         Returns Lambda function recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_lambda_function_recommendations)
         """
 
     def get_recommendation_summaries(
-        self, *, accountIds: Sequence[str] = None, nextToken: str = None, maxResults: int = None
+        self, *, accountIds: Sequence[str] = ..., nextToken: str = ..., maxResults: int = ...
     ) -> GetRecommendationSummariesResponseTypeDef:
         """
         Returns the optimization findings for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_recommendation_summaries)
         """
 
     def update_enrollment_status(
-        self, *, status: StatusType, includeMemberAccounts: bool = None
+        self, *, status: StatusType, includeMemberAccounts: bool = ...
     ) -> UpdateEnrollmentStatusResponseTypeDef:
         """
         Updates the enrollment (opt in and opt out) status of an account to the Compute
         Optimizer service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#update_enrollment_status)
         """
